import Foundation
import ITWebAPI
// MARK: Factory
open class DeviceWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    open var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open enum BodyType{
        case requestBody
        case responseBody
    }

    open func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/api/device/mtcc/queryMopedBatteryStatusInfo":
				if type == .requestBody {
                    body = DevicePostQueryMopedBatteryStatusInfo()
                } else {
                    body = DeviceRetQueryMopedBatteryStatusInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/mtcc/statsMopedBatteryStatusInfo":
				if type == .requestBody {
                    body = DevicePostStatsMopedBatteryStatusInfo()
                } else {
                    body = DeviceRetStatsMopedBatteryStatusInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getDeviceStatus":
				if type == .requestBody {
                    body = DevicePostBikeStatus()
                } else {
                    body = DeviceRetBikeStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getDeviceStatusByMac":
				if type == .requestBody {
                    body = DevicePostMacBikeStatus()
                } else {
                    body = DeviceRetMacBikeStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getDeviceStatusByBike":
				if type == .requestBody {
                    body = DevicePostDeviceStatus()
                } else {
                    body = DeviceRetDeviceStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/saveDeviceStatus":
				if type == .requestBody {
                    body = DevicePostSaveDeviceStatus()
                } else {
                    body = DeviceRetSaveDeviceStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getCp4ByMac":
				if type == .requestBody {
                    body = DeviceGetNailMacStatus()
                } else {
                    body = DeviceRetNailDevStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/saveNailPileByMac":
				if type == .requestBody {
                    body = DevicePostUpdateNailPile()
                } else {
                    body = DeviceRetUpdateNailPile(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/convertDeviceId":
				if type == .requestBody {
                    body = DevicePostConvertDeviceId()
                } else {
                    body = DeviceRetConvertDeviceId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/returnBikeLocReq":
				if type == .requestBody {
                    body = DevicePostReturnBikeLocReq()
                } else {
                    body = DeviceRetReturnBikeLocReq(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getBhtDeviceStatus":
				if type == .requestBody {
                    body = DevicePostBhtDeviceStatus()
                } else {
                    body = DeviceRetBhtDeviceStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getElectricFence":
				if type == .requestBody {
                    body = DevicePostGetElectricFence()
                } else {
                    body = DeviceRetGetElectricFence(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getElectricFenceBySiteId":
				if type == .requestBody {
                    body = DevicePostGetElectricFenceBySiteId()
                } else {
                    body = DeviceRetGetElectricFenceBySiteId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getBikePosition":
				if type == .requestBody {
                    body = DevicePostGetBikePosition()
                } else {
                    body = DeviceRetGetBikePosition(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getBikeDevice":
				if type == .requestBody {
                    body = DevicePostGetBikeDevice()
                } else {
                    body = DeviceRetGetBikeDevice(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/area/saveArea":
				if type == .requestBody {
                    body = DevicePostSaveArea()
                } else {
                    body = DeviceRetSaveArea(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/area/queryArea":
				if type == .requestBody {
                    body = DevicePostQueryArea()
                } else {
                    body = DeviceRetQueryArea(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/area/areaSiteBind":
				if type == .requestBody {
                    body = DevicePostAreaSiteBind()
                } else {
                    body = DeviceRetAreaSiteBind(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/area/removeArea":
				if type == .requestBody {
                    body = DevicePostRemoveArea()
                } else {
                    body = DeviceRetRemoveArea(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getSiteInfo":
				if type == .requestBody {
                    body = DeviceGetSiteInfo()
                } else {
                    body = DeviceRetSiteInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/saveSiteInfo":
				if type == .requestBody {
                    body = DevicePostSaveSiteInfo()
                } else {
                    body = DeviceRetSaveSiteInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getDeviceInTheStation":
				if type == .requestBody {
                    body = DevicePostDeviceInTheStation()
                } else {
                    body = DeviceRetDeviceInTheStation(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/getBikeBindInfo":
				if type == .requestBody {
                    body = DevicePostBikeBindInfo()
                } else {
                    body = DeviceRetBikeBindInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/heartBeat":
				if type == .requestBody {
                    body = DevicePostHeartBeat()
                } else {
                    body = DeviceRetHeartBeat(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/scanSwitch":
				if type == .requestBody {
                    body = DevicePostScanSwitch()
                } else {
                    body = DeviceRetScanSwitch(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/deviceRestart":
				if type == .requestBody {
                    body = DevicePostDeviceRestart()
                } else {
                    body = DeviceRetDeviceRestart(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/logUpload":
				if type == .requestBody {
                    body = DevicePostLogUpload()
                } else {
                    body = DeviceRetLogUpload(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/uidRegister":
				if type == .requestBody {
                    body = DevicePostUidRegister()
                } else {
                    body = DeviceRetUidRegister(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/deviceUpgrade":
				if type == .requestBody {
                    body = DevicePostDeviceUpgrade()
                } else {
                    body = DeviceRetDeviceUpgrade(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/audioFileDistribution":
				if type == .requestBody {
                    body = DevicePostAudioFileDistribution()
                } else {
                    body = DeviceRetAudioFileDistribution(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/abnormalReport":
				if type == .requestBody {
                    body = DevicePostAbnormalReport()
                } else {
                    body = DeviceRetAbnormalReport(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/heartBeatConfig":
				if type == .requestBody {
                    body = DevicePostHeartBeatConfig()
                } else {
                    body = DeviceRetHeartBeatConfig(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/restart2640":
				if type == .requestBody {
                    body = DevicePostRestart2640()
                } else {
                    body = DeviceRetRestart2640(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/batteryLockSwitch":
				if type == .requestBody {
                    body = DevicePostBatteryLockSwitch()
                } else {
                    body = DeviceRetBatteryLockSwitch(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/mopedOnlineAndOffLine":
				if type == .requestBody {
                    body = DevicePostMopedOnlineAndOffLine()
                } else {
                    body = DeviceRetMopedOnlineAndOffLine(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/bluetoothScan":
				if type == .requestBody {
                    body = DevicePostBluetoothScan()
                } else {
                    body = DeviceRetBluetoothScan(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/getBatteryStaByDevId":
				if type == .requestBody {
                    body = DevicePostGetBatteryStaByDevId()
                } else {
                    body = DeviceRetGetBatteryStaByDevId(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/updateBatteryStatus":
				if type == .requestBody {
                    body = DevicePostUpdateBatteryStatus()
                } else {
                    body = DeviceRetUpdateBatteryStatus(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/bike/conditionBikeBack":
				if type == .requestBody {
                    body = DevicePostConditionBikeBack()
                } else {
                    body = DeviceRetConditionBikeBack(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/api/device/config/query":
				if type == .requestBody {
                    body = DevicePostDeviceConfigQuery()
                } else {
                    body = DeviceRetDeviceConfigQuery(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class DevicePostQueryMopedBatteryStatusInfo : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var batteryId:String?
    							open var deviceId:String?
    							open var batteryStatus:String?
    								
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let batteryId_ = self.batteryId;
																					let deviceId_ = self.deviceId;
																					let batteryStatus_ = self.batteryStatus;
																			
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostQueryMopedBatteryStatusInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:7,field:"batteryId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:7,value:batteryId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:7,field:"batteryId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:7,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:7,field:"batteryStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:7,value:batteryStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:7,field:"batteryStatus",body:self))
																			result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostQueryMopedBatteryStatusInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetQueryMopedBatteryStatusInfo : BaseITWebAPIBody {
	
	//
												open var totCount:String?
    				    		//----->list
			fileprivate var data = [DeviceBatteryStatusInfoWebApi]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											totCount = visitableSource.getValue("totCount")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( BatteryStatusInfoWebApi (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addData(subBody:BatteryStatusInfoWebApi) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [BatteryStatusInfoWebApi]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class DeviceBatteryStatusInfoWebApi : BaseITWebAPIBody {
	
	//
									open var batteryId:String?
    																			open var batteryPackModel:String?
    							open var batterySoftwareVersion:String?
    							open var batteryHardwareVersion:String?
    										open var batteryManufacturer:String?
    							open var batteryProductionTime:String?
    							open var deviceId:String?
    							open var cityCode:String?
    							open var batteryStatus:String?
    							open var operateUid:String?
    							open var operateName:String?
    							open var updateTime:String?
    							open var createTime:String?
    							open var operateTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/queryMopedBatteryStatusInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																									batteryId = visitableSource.getValue("batteryId")
																																																							batteryPackModel = visitableSource.getValue("batteryPackModel")
																											batterySoftwareVersion = visitableSource.getValue("batterySoftwareVersion")
																											batteryHardwareVersion = visitableSource.getValue("batteryHardwareVersion")
																																		batteryManufacturer = visitableSource.getValue("batteryManufacturer")
																											batteryProductionTime = visitableSource.getValue("batteryProductionTime")
																											deviceId = visitableSource.getValue("deviceId")
																											cityCode = visitableSource.getValue("cityCode")
																											batteryStatus = visitableSource.getValue("batteryStatus")
																											operateUid = visitableSource.getValue("operateUid")
																											operateName = visitableSource.getValue("operateName")
																											updateTime = visitableSource.getValue("updateTime")
																											createTime = visitableSource.getValue("createTime")
																											operateTime = visitableSource.getValue("operateTime")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DevicePostStatsMopedBatteryStatusInfo : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/statsMopedBatteryStatusInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/statsMopedBatteryStatusInfo"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostStatsMopedBatteryStatusInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostStatsMopedBatteryStatusInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetStatsMopedBatteryStatusInfo : BaseITWebAPIBody {
	
	//
												open var totCount:String?
    							open var normal:String?
    							open var offShelf:String?
    							open var charging:String?
    							open var inHouse:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/statsMopedBatteryStatusInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/mtcc/statsMopedBatteryStatusInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											totCount = visitableSource.getValue("totCount")
																											normal = visitableSource.getValue("normal")
																											offShelf = visitableSource.getValue("offShelf")
																											charging = visitableSource.getValue("charging")
																											inHouse = visitableSource.getValue("inHouse")
															}

	//-------> list
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostBikeStatus : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatus"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostBikeStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostBikeStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetBikeStatus : BaseITWebAPIBody {
	
	//
												open var bikeId:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bikeId = visitableSource.getValue("bikeId")
																						}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostMacBikeStatus : BaseITWebAPIBody {
	
	//
						open var mac:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByMac"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let mac_ = self.mac;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostMacBikeStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"mac",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:mac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"mac",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostMacBikeStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetMacBikeStatus : BaseITWebAPIBody {
	
	//
												open var bikeId:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByMac"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bikeId = visitableSource.getValue("bikeId")
																						}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostDeviceStatus : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByBike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByBike"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let bikeId_ = self.bikeId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostDeviceStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostDeviceStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetDeviceStatus : BaseITWebAPIBody {
	
	//
												open var bikeId:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByBike"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceStatusByBike"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bikeId = visitableSource.getValue("bikeId")
																						}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostSaveDeviceStatus : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveDeviceStatus"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
							
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostSaveDeviceStatus",body:self))
													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostSaveDeviceStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    								}

		
open class DeviceRetSaveDeviceStatus : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveDeviceStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DeviceGetNailMacStatus : BaseITWebAPIBody {
	
	//
						open var nailMac:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getCp4ByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getCp4ByMac"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let nailMac_ = self.nailMac;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DeviceGetNailMacStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"nailMac",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:nailMac_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"nailMac",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DeviceGetNailMacStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetNailDevStatus : BaseITWebAPIBody {
	
	//
													
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getCp4ByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getCp4ByMac"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																													}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostUpdateNailPile : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveNailPileByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveNailPileByMac"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
							
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostUpdateNailPile",body:self))
													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostUpdateNailPile",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    								}

		
open class DeviceRetUpdateNailPile : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveNailPileByMac"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveNailPileByMac"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostConvertDeviceId : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var bikeId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/convertDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/convertDeviceId"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let bikeId_ = self.bikeId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostConvertDeviceId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostConvertDeviceId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetConvertDeviceId : BaseITWebAPIBody {
	
	//
												open var deviceId:String?
    							open var bikeId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/convertDeviceId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/convertDeviceId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											deviceId = visitableSource.getValue("deviceId")
																											bikeId = visitableSource.getValue("bikeId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostReturnBikeLocReq : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var lngLat:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/returnBikeLocReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/returnBikeLocReq"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let lngLat_ = self.lngLat;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostReturnBikeLocReq",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"lngLat",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:lngLat_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"lngLat",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostReturnBikeLocReq",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetReturnBikeLocReq : BaseITWebAPIBody {
	
	//
												open var siteId:String?
    							open var whetherInEnclosure:String?
    							open var enclosureName:String?
    							open var electricFenceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/returnBikeLocReq"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/returnBikeLocReq"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											siteId = visitableSource.getValue("siteId")
																											whetherInEnclosure = visitableSource.getValue("whetherInEnclosure")
																											enclosureName = visitableSource.getValue("enclosureName")
																											electricFenceId = visitableSource.getValue("electricFenceId")
															}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostBhtDeviceStatus : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBhtDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBhtDeviceStatus"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let bikeId_ = self.bikeId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostBhtDeviceStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostBhtDeviceStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetBhtDeviceStatus : BaseITWebAPIBody {
	
	//
												open var bikeId:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBhtDeviceStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBhtDeviceStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bikeId = visitableSource.getValue("bikeId")
																						}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostGetElectricFence : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var appId:String?
    							open var maxDistance:String?
    							open var lngLat:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let appId_ = self.appId;
																					let maxDistance_ = self.maxDistance;
																					let lngLat_ = self.lngLat;
														
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostGetElectricFence",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"appId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:appId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"appId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"maxDistance",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:maxDistance_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"maxDistance",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"lngLat",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:lngLat_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"lngLat",body:self))
														result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostGetElectricFence",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetGetElectricFence : BaseITWebAPIBody {
	
	//
									    		//----->list
			fileprivate var data = [DeviceElectricFenceList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																					//----->list
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( ElectricFenceList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    			    open func addData(subBody:ElectricFenceList) -> Void{
	        data.append(subBody)
	    }

	    open func getData() -> [ElectricFenceList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																			
open class DeviceElectricFenceList : BaseITWebAPIBody {
	
	//
						open var siteId:String?
    							open var serviceId:String?
    							open var cityCode:String?
    							open var electricFenceId:String?
    							open var name:String?
    							open var loc:String?
    							open var deviceCount:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFence"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		siteId = visitableSource.getValue("siteId")
																											serviceId = visitableSource.getValue("serviceId")
																											cityCode = visitableSource.getValue("cityCode")
																											electricFenceId = visitableSource.getValue("electricFenceId")
																											name = visitableSource.getValue("name")
																											loc = visitableSource.getValue("loc")
																											deviceCount = visitableSource.getValue("deviceCount")
																						}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DevicePostGetElectricFenceBySiteId : BaseITWebAPIBody {
	
	//
						open var siteId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFenceBySiteId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFenceBySiteId"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let siteId_ = self.siteId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostGetElectricFenceBySiteId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"siteId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:siteId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"siteId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostGetElectricFenceBySiteId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetGetElectricFenceBySiteId : BaseITWebAPIBody {
	
	//
												open var siteId:String?
    							open var serviceId:String?
    							open var cityCode:String?
    							open var electricFenceId:String?
    							open var name:String?
    							open var loc:String?
    							open var address:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFenceBySiteId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getElectricFenceBySiteId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											siteId = visitableSource.getValue("siteId")
																											serviceId = visitableSource.getValue("serviceId")
																											cityCode = visitableSource.getValue("cityCode")
																											electricFenceId = visitableSource.getValue("electricFenceId")
																											name = visitableSource.getValue("name")
																											loc = visitableSource.getValue("loc")
																											address = visitableSource.getValue("address")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostGetBikePosition : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var cityCode:String?
    							open var coordinateType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikePosition"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikePosition"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let bikeId_ = self.bikeId;
																					let cityCode_ = self.cityCode;
																					let coordinateType_ = self.coordinateType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostGetBikePosition",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"coordinateType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:coordinateType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"coordinateType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostGetBikePosition",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetGetBikePosition : BaseITWebAPIBody {
	
	//
												open var lonLat:String?
    							open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikePosition"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikePosition"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											lonLat = visitableSource.getValue("lonLat")
																											deviceId = visitableSource.getValue("deviceId")
															}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostGetBikeDevice : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var siteNo:String?
    							open var partNo:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikeDevice"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikeDevice"
        	}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let siteNo_ = self.siteNo;
																					let partNo_ = self.partNo;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostGetBikeDevice",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"siteNo",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:siteNo_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"siteNo",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"partNo",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:partNo_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"partNo",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostGetBikeDevice",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetGetBikeDevice : BaseITWebAPIBody {
	
	//
												open var bikeId:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikeDevice"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBikeDevice"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bikeId = visitableSource.getValue("bikeId")
																						}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																							}

		
open class DevicePostSaveArea : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/saveArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/saveArea"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
							
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostSaveArea",body:self))
													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostSaveArea",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    								}

		
open class DeviceRetSaveArea : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/saveArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/saveArea"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostQueryArea : BaseITWebAPIBody {
	
	//
						open var areaId:String?
    							open var serviceId:String?
    								
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let areaId_ = self.areaId;
																					let serviceId_ = self.serviceId;
																			
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostQueryArea",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"areaId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:areaId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"areaId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"serviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:serviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"serviceId",body:self))
																			result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostQueryArea",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetQueryArea : BaseITWebAPIBody {
	
	//
												open var count:String?
    				    		//----->list
			fileprivate var siteAreas = [DeviceSiteArea]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											count = visitableSource.getValue("count")
																					//----->list
					for visitableSource in visitableSource.getSubSource("siteAreas") {
						siteAreas .append( SiteArea (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addSiteAreas(subBody:SiteArea) -> Void{
	        data.append(subBody)
	    }

	    open func getSiteAreas() -> [SiteArea]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class DeviceSiteArea : BaseITWebAPIBody {
	
	//
	
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/queryArea"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
						}

	//-------> list
	
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DevicePostAreaSiteBind : BaseITWebAPIBody {
	
	//
						open var areaId:String?
    				    		//----->list
			fileprivate var siteIds = [DeviceSiteId]()
			//>-----
								open var siteType:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
        	}

	//-------> list
			    			    open func addSiteIds(subBody:SiteId) -> Void{
	        data.append(subBody)
	    }

	    open func getSiteIds() -> [SiteId]{
	        return data
	    }
	        		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let areaId_ = self.areaId;
																													let siteType_ = self.siteType;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostAreaSiteBind",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"areaId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:areaId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"areaId",body:self))
												//----->list
				result.append(vo.onFieldBegin(.array,index:2,length:4,field:"siteIds",body:self))
				var siteIds_index_ = 1;
				var siteIds_length_ = siteIds .count
				for object in self.siteIds {
					result.append(object.encode(siteIds_index_,lenght:siteIds_length_,visitableObject:visitableObject,secureKeys:secureKeys)) ?? "")
					siteIds_index_ ++;
				}
				result.append(vo.onFieldEnd(.array,index:2,length:4,field:"siteIds",body:self))
				//>-----
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"siteType",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:siteType_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"siteType",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostAreaSiteBind",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    														
open class DeviceSiteId : BaseITWebAPIBody {
	
	//
						open var siteId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		siteId = visitableSource.getValue("siteId")
															}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
											}

		
open class DeviceRetAreaSiteBind : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/areaSiteBind"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostRemoveArea : BaseITWebAPIBody {
	
	//
						open var areaId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/removeArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/removeArea"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let areaId_ = self.areaId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostRemoveArea",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"areaId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:areaId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"areaId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostRemoveArea",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetRemoveArea : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/removeArea"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/area/removeArea"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DeviceGetSiteInfo : BaseITWebAPIBody {
	
	//
						open var siteId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getSiteInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getSiteInfo"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let siteId_ = self.siteId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DeviceGetSiteInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"siteId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:siteId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"siteId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DeviceGetSiteInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetSiteInfo : BaseITWebAPIBody {
	
	//
												open var cityCode:String?
    							open var deviceId:String?
    							open var deviceName:String?
    							open var coordinate:String?
    							open var coordType:String?
    							open var address:String?
    							open var status:String?
    							open var siteStatus:String?
    													open var areaId:String?
    							open var areaName:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getSiteInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getSiteInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											cityCode = visitableSource.getValue("cityCode")
																											deviceId = visitableSource.getValue("deviceId")
																											deviceName = visitableSource.getValue("deviceName")
																											coordinate = visitableSource.getValue("coordinate")
																											coordType = visitableSource.getValue("coordType")
																											address = visitableSource.getValue("address")
																											status = visitableSource.getValue("status")
																											siteStatus = visitableSource.getValue("siteStatus")
																																									areaId = visitableSource.getValue("areaId")
																											areaName = visitableSource.getValue("areaName")
															}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostSaveSiteInfo : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveSiteInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveSiteInfo"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
							
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostSaveSiteInfo",body:self))
													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostSaveSiteInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    								}

		
open class DeviceRetSaveSiteInfo : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveSiteInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/saveSiteInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostDeviceInTheStation : BaseITWebAPIBody {
	
	//
						open var siteId:String?
    							open var cityCode:String?
    								
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let siteId_ = self.siteId;
																					let cityCode_ = self.cityCode;
																			
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostDeviceInTheStation",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"siteId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:siteId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"siteId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"cityCode",body:self))
																			result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostDeviceInTheStation",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetDeviceInTheStation : BaseITWebAPIBody {
	
	//
												open var count:String?
    				    		//----->list
			fileprivate var devices = [DeviceDevice]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											count = visitableSource.getValue("count")
																					//----->list
					for visitableSource in visitableSource.getSubSource("devices") {
						devices .append( Device (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addDevices(subBody:Device) -> Void{
	        data.append(subBody)
	    }

	    open func getDevices() -> [Device]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class DeviceDevice : BaseITWebAPIBody {
	
	//
	
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getDeviceInTheStation"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
						}

	//-------> list
	
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DevicePostBikeBindInfo : BaseITWebAPIBody {
	
	//
						open var cityCode:String?
    							open var deviceIdOrBikeId:String?
    							open var areaName:String?
    								
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let cityCode_ = self.cityCode;
																					let deviceIdOrBikeId_ = self.deviceIdOrBikeId;
																					let areaName_ = self.areaName;
																			
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostBikeBindInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"cityCode",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"deviceIdOrBikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:deviceIdOrBikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"deviceIdOrBikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"areaName",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:areaName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"areaName",body:self))
																			result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostBikeBindInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetBikeBindInfo : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    							open var count:String?
    				    		//----->list
			fileprivate var bikeBindInfos = [DeviceBikeBindEntry]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
																											count = visitableSource.getValue("count")
																					//----->list
					for visitableSource in visitableSource.getSubSource("bikeBindInfos") {
						bikeBindInfos .append( BikeBindEntry (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> list
			    		    		    			    open func addBikeBindInfos(subBody:BikeBindEntry) -> Void{
	        data.append(subBody)
	    }

	    open func getBikeBindInfos() -> [BikeBindEntry]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class DeviceBikeBindEntry : BaseITWebAPIBody {
	
	//
	
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/getBikeBindInfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
						}

	//-------> list
	
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DevicePostHeartBeat : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    																																																								
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeat"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																																																																																																			
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostHeartBeat",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:20,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:20,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:20,field:"deviceId",body:self))
																																																																																																			result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostHeartBeat",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    																																																																																																		}

		
open class DeviceRetHeartBeat : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeat"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeat"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostScanSwitch : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    											
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/scanSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/scanSwitch"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																								
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostScanSwitch",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																								result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostScanSwitch",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetScanSwitch : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/scanSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/scanSwitch"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostDeviceRestart : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    											
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceRestart"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceRestart"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																								
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostDeviceRestart",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																								result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostDeviceRestart",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetDeviceRestart : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceRestart"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceRestart"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostLogUpload : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    													open var loggerAddress:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/logUpload"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/logUpload"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																															let loggerAddress_ = self.loggerAddress;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostLogUpload",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																						result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"loggerAddress",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:loggerAddress_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"loggerAddress",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostLogUpload",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetLogUpload : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/logUpload"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/logUpload"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostUidRegister : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    													open var moduleImei:String?
    							open var simCardCcid:String?
    							open var simCardImsi:String?
    							open var moduleVersion:String?
    							open var bluetoothVersion:String?
    							open var bluetoothMAC:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/uidRegister"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/uidRegister"
        	}

	//-------> list
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																															let moduleImei_ = self.moduleImei;
																					let simCardCcid_ = self.simCardCcid;
																					let simCardImsi_ = self.simCardImsi;
																					let moduleVersion_ = self.moduleVersion;
																					let bluetoothVersion_ = self.bluetoothVersion;
																					let bluetoothMAC_ = self.bluetoothMAC;
														
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostUidRegister",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:11,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:11,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:11,field:"deviceId",body:self))
																						result.append(vo.onFieldBegin(.flat,index:4,length:11,field:"moduleImei",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:11,value:moduleImei_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:11,field:"moduleImei",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:11,field:"simCardCcid",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:11,value:simCardCcid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:11,field:"simCardCcid",body:self))
												result.append(vo.onFieldBegin(.flat,index:6,length:11,field:"simCardImsi",body:self))
				result.append(vo.onFieldValue(.flat,index:6,length:11,value:simCardImsi_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:6,length:11,field:"simCardImsi",body:self))
												result.append(vo.onFieldBegin(.flat,index:7,length:11,field:"moduleVersion",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:11,value:moduleVersion_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:11,field:"moduleVersion",body:self))
												result.append(vo.onFieldBegin(.flat,index:8,length:11,field:"bluetoothVersion",body:self))
				result.append(vo.onFieldValue(.flat,index:8,length:11,value:bluetoothVersion_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:8,length:11,field:"bluetoothVersion",body:self))
												result.append(vo.onFieldBegin(.flat,index:9,length:11,field:"bluetoothMAC",body:self))
				result.append(vo.onFieldValue(.flat,index:9,length:11,value:bluetoothMAC_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:9,length:11,field:"bluetoothMAC",body:self))
														result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostUidRegister",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    																																																					}

		
open class DeviceRetUidRegister : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/uidRegister"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/uidRegister"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostDeviceUpgrade : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    																open var version:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceUpgrade"
        	}

	//-------> list
			    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																																				let version_ = self.version;
														
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostDeviceUpgrade",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:7,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:7,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:7,field:"deviceId",body:self))
																											result.append(vo.onFieldBegin(.flat,index:5,length:7,field:"version",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:7,value:version_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:7,field:"version",body:self))
														result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostDeviceUpgrade",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetDeviceUpgrade : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceUpgrade"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/deviceUpgrade"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostAudioFileDistribution : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    														
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/audioFileDistribution"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/audioFileDistribution"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																													
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostAudioFileDistribution",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"deviceId",body:self))
																													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostAudioFileDistribution",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetAudioFileDistribution : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/audioFileDistribution"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/audioFileDistribution"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostAbnormalReport : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    														
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/abnormalReport"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/abnormalReport"
        	}

	//-------> list
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																													
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostAbnormalReport",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"deviceId",body:self))
																													result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostAbnormalReport",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetAbnormalReport : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/abnormalReport"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/abnormalReport"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostHeartBeatConfig : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    											
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeatConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeatConfig"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																								
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostHeartBeatConfig",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																								result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostHeartBeatConfig",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetHeartBeatConfig : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeatConfig"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/heartBeatConfig"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostRestart2640 : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    											
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/restart2640"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/restart2640"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																								
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostRestart2640",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																								result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostRestart2640",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetRestart2640 : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/restart2640"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/restart2640"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostBatteryLockSwitch : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    											
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/batteryLockSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/batteryLockSwitch"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																								
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostBatteryLockSwitch",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"deviceId",body:self))
																								result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostBatteryLockSwitch",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetBatteryLockSwitch : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/batteryLockSwitch"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/batteryLockSwitch"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostMopedOnlineAndOffLine : BaseITWebAPIBody {
	
	//
									open var status:String?
    							open var productKey:String?
    							open var deviceName:String?
    													open var clientIp:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/mopedOnlineAndOffLine"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/mopedOnlineAndOffLine"
        	}

	//-------> list
			    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
																			let status_ = self.status;
																					let productKey_ = self.productKey;
																					let deviceName_ = self.deviceName;
																															let clientIp_ = self.clientIp;
														
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostMopedOnlineAndOffLine",body:self))
																result.append(vo.onFieldBegin(.flat,index:2,length:9,field:"status",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:9,value:status_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:9,field:"status",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:9,field:"productKey",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:9,value:productKey_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:9,field:"productKey",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:9,field:"deviceName",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:9,value:deviceName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:9,field:"deviceName",body:self))
																						result.append(vo.onFieldBegin(.flat,index:7,length:9,field:"clientIp",body:self))
				result.append(vo.onFieldValue(.flat,index:7,length:9,value:clientIp_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:7,length:9,field:"clientIp",body:self))
														result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostMopedOnlineAndOffLine",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetMopedOnlineAndOffLine : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/mopedOnlineAndOffLine"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/mopedOnlineAndOffLine"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostBluetoothScan : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    													    		//----->list
			fileprivate var deviceDataList = [DeviceDeviceData]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
        	}

	//-------> list
			    		    		    		    			    open func addDeviceDataList(subBody:DeviceData) -> Void{
	        data.append(subBody)
	    }

	    open func getDeviceDataList() -> [DeviceData]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																																
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostBluetoothScan",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"deviceId",body:self))
																											//----->list
				result.append(vo.onFieldBegin(.array,index:5,length:6,field:"deviceDataList",body:self))
				var deviceDataList_index_ = 1;
				var deviceDataList_length_ = deviceDataList .count
				for object in self.deviceDataList {
					result.append(object.encode(deviceDataList_index_,lenght:deviceDataList_length_,visitableObject:visitableObject,secureKeys:secureKeys)) ?? "")
					deviceDataList_index_ ++;
				}
				result.append(vo.onFieldEnd(.array,index:5,length:6,field:"deviceDataList",body:self))
				//>-----
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostBluetoothScan",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    																													
open class DeviceDeviceData : BaseITWebAPIBody {
	
	//
	
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
						}

	//-------> list
	
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class DeviceRetBluetoothScan : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/bluetoothScan"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostGetBatteryStaByDevId : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBatteryStaByDevId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBatteryStaByDevId"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostGetBatteryStaByDevId",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"deviceId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostGetBatteryStaByDevId",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetGetBatteryStaByDevId : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    					
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBatteryStaByDevId"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/getBatteryStaByDevId"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
																						}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																		}

		
open class DevicePostUpdateBatteryStatus : BaseITWebAPIBody {
	
	//
						open var batteryId:String?
    							open var operateUid:String?
    							open var operateName:String?
    							open var batteryStatus:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/updateBatteryStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/updateBatteryStatus"
        	}

	//-------> list
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let batteryId_ = self.batteryId;
																					let operateUid_ = self.operateUid;
																					let operateName_ = self.operateName;
																					let batteryStatus_ = self.batteryStatus;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostUpdateBatteryStatus",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"batteryId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:batteryId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"batteryId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"operateUid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:operateUid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"operateUid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"operateName",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:operateName_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"operateName",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"batteryStatus",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:batteryStatus_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"batteryStatus",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostUpdateBatteryStatus",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetUpdateBatteryStatus : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/updateBatteryStatus"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/updateBatteryStatus"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostConditionBikeBack : BaseITWebAPIBody {
	
	//
						open var bikeId:String?
    							open var cityCode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/conditionBikeBack"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/conditionBikeBack"
        	}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let bikeId_ = self.bikeId;
																					let cityCode_ = self.cityCode;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostConditionBikeBack",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"bikeId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:bikeId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"bikeId",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityCode",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityCode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityCode",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostConditionBikeBack",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetConditionBikeBack : BaseITWebAPIBody {
	
	//
									open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/conditionBikeBack"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/bike/conditionBikeBack"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																									retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class DevicePostDeviceConfigQuery : BaseITWebAPIBody {
	
	//
						open var deviceId:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/config/query"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/config/query"
        	}

	//-------> list
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let deviceId_ = self.deviceId;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"DevicePostDeviceConfigQuery",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"deviceId",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:deviceId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"deviceId",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"DevicePostDeviceConfigQuery",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class DeviceRetDeviceConfigQuery : BaseITWebAPIBody {
	
	//
						open var retCode:String?
    							open var retMsg:String?
    		
	required public init(){
		super.init()
		self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/config/query"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "52"
		self.appName_ = "device"
		self.mapping_ = "/api/device/config/query"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retCode = visitableSource.getValue("retCode")
																											retMsg = visitableSource.getValue("retMsg")
															}

	//-------> list
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_token } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
