import Foundation
import ITWebAPI
// MARK: Factory
open class MtWebAPIContext : ITWebAPIContext{
	required public init(){}
    open var visitablePair:ITVisitablePair = ITXmlVisitablePair()
    fileprivate var secureKeys = [String:ITSecureKey]()
    open func setSecureKey(_ secureKey:ITSecureKey?) -> ITWebAPIContext?{
        if let secureKey_ = secureKey {
            secureKeys[secureKey_.name] = secureKey_
        }
        return self
    }

    open func getSecureKey(_ keyName:String) -> ITSecureKey? {
        return self.secureKeys[keyName]
    }

    open func getSecureKeys() -> [String:ITSecureKey]? {
        return self.secureKeys
    }

    open func createRequestBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createRequestBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody{
        if secureKey == nil {
            return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .requestBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    open func createResponseBody(_ requestMapping:String) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: nil, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?) -> ITWebAPIBody {
        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
    }
    open func createResponseBody(_ requestMapping:String,content:String?,secureKey:ITSecureKey?) -> ITWebAPIBody {
        if secureKey == nil {
            return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: self.secureKeys)
        }

        return self.createBody(type: .responseBody, requestMapping: requestMapping, content: content, secureKeys: [secureKey!.name:secureKey!])
    }

    fileprivate enum BodyType{
        case requestBody
        case responseBody
    }

    fileprivate func createBody(type:BodyType,requestMapping:String,content:String?,secureKeys:[String:ITSecureKey]) -> ITWebAPIBody{
        var body:ITWebAPIBody
        switch(requestMapping){
        				case "/bikemt/security/getclientkey":
				if type == .requestBody {
                    body = postClientKey()
                } else {
                    body = retClientKey(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/getcitytoken":
				if type == .requestBody {
                    body = postCityToken()
                } else {
                    body = retCityToken(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/getregistvcode":
				if type == .requestBody {
                    body = postGetRegistVcode()
                } else {
                    body = retGetRegistVcode(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/getresetpwdvcode":
				if type == .requestBody {
                    body = postGetResetPwdVcode()
                } else {
                    body = retGetResetPwdVcode(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/getphonevcode":
				if type == .requestBody {
                    body = PostGetPhoneVcode()
                } else {
                    body = RetGetPhoneVcode(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/member/register":
				if type == .requestBody {
                    body = postUserReg()
                } else {
                    body = retUserReg(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/clientlogin":
				if type == .requestBody {
                    body = postClientLogin()
                } else {
                    body = retClientLogin(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/vcodeLogin":
				if type == .requestBody {
                    body = PostVCodeLogin()
                } else {
                    body = RetVCodeLogin(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/trustlogin":
				if type == .requestBody {
                    body = postTrustLogin()
                } else {
                    body = retTrustLogin(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/member/updatepwd":
				if type == .requestBody {
                    body = postUpdatePwd()
                } else {
                    body = retUpdatePwd(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/member/resetpwd":
				if type == .requestBody {
                    body = postResetPwd()
                } else {
                    body = retResetPwd(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/member/bindnewphone":
				if type == .requestBody {
                    body = postBindNewPhone()
                } else {
                    body = retBindNewPhone(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/member/getmemberinfo":
				if type == .requestBody {
                    body = postGetMemberInfo()
                } else {
                    body = retGetMemberInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/security/clientlogout":
				if type == .requestBody {
                    body = postClientLogout()
                } else {
                    body = retClientLogout(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/manager/sysinfo":
				if type == .requestBody {
                    body = postSysInfo()
                } else {
                    body = retSysInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/business/citylistinfo":
				if type == .requestBody {
                    body = postCityListInfo()
                } else {
                    body = retCityListInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/business/citybaseinfo":
				if type == .requestBody {
                    body = postCityBaseInfo()
                } else {
                    body = retCityBaseInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/business/memberbizinfo":
				if type == .requestBody {
                    body = postMemberBizInfo()
                } else {
                    body = retMemberBizInfo(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/manager/submitMail":
				if type == .requestBody {
                    body = postSubmitMail()
                } else {
                    body = retSubmitMail(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/manager/listMail":
				if type == .requestBody {
                    body = postListMail()
                } else {
                    body = retListMail(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						case "/bikemt/manager/listAnnc":
				if type == .requestBody {
                    body = postListAnnc()
                } else {
                    body = retListAnnc(visitableSource: self.visitablePair.getVisitableSource(content ?? ""),secureKeys:secureKeys)
                }
            break
						default:
			body = BaseITWebAPIBody()
        }
        body.context = self
        return body
    }
}


		
open class postClientKey : BaseITWebAPIBody {
	
	//
						open var pubkey:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getclientkey"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getclientkey"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let pubkey_ = self.pubkey;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("pubkey=" + (pubkey_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postClientKey",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"pubkey",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:pubkey_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"pubkey",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postClientKey",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retClientKey : BaseITWebAPIBody {
	
	//
															open var key:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getclientkey"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getclientkey"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											clientid = visitableSource.getValue("clientid")
																											key = secureKeys["RSA"]?.decrypt(original: visitableSource.getValue("key"))
															}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postCityToken : BaseITWebAPIBody {
	
	//
									open var cityid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getcitytoken"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getcitytoken"
        	}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let cityid_ = self.cityid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&cityid=" + (cityid_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postCityToken",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"cityid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:cityid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"cityid",body:self))
									result.append(vo.onFieldBegin(.flat,index:3,length:3,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:3,length:3,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:3,length:3,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postCityToken",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retCityToken : BaseITWebAPIBody {
	
	//
												open var cityid:String?
    							open var accesstoken:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getcitytoken"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getcitytoken"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											cityid = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("cityid"))
																											accesstoken = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("accesstoken"))
															}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postGetRegistVcode : BaseITWebAPIBody {
	
	//
						open var appid:String?
    										open var phone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getregistvcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getregistvcode"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
																					let clientid_ = self.clientid;
																					let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
																						md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&phone=" + (phone_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postGetRegistVcode",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"phone",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postGetRegistVcode",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retGetRegistVcode : BaseITWebAPIBody {
	
	//
												open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getregistvcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getregistvcode"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											checkcode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("checkcode"))
															}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postGetResetPwdVcode : BaseITWebAPIBody {
	
	//
						open var appid:String?
    										open var phone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getresetpwdvcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getresetpwdvcode"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
																					let clientid_ = self.clientid;
																					let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
																						md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&phone=" + (phone_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postGetResetPwdVcode",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"phone",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postGetResetPwdVcode",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retGetResetPwdVcode : BaseITWebAPIBody {
	
	//
												open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getresetpwdvcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getresetpwdvcode"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											checkcode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("checkcode"))
															}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class PostGetPhoneVcode : BaseITWebAPIBody {
	
	//
						open var appid:String?
    										open var phone:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getphonevcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getphonevcode"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
																					let clientid_ = self.clientid;
																					let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
																						md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&phone=" + (phone_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"PostGetPhoneVcode",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"appid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"phone",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"PostGetPhoneVcode",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class RetGetPhoneVcode : BaseITWebAPIBody {
	
	//
												open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getphonevcode"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/getphonevcode"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											checkcode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("checkcode"))
															}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postUserReg : BaseITWebAPIBody {
	
	//
									open var phone:String?
    							open var password:String?
    							open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/register"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/register"
        	}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
																					let password_ = secureKeys?["AES"]?.encrypt(original: self.password) ?? ""
																					let checkcode_ = secureKeys?["AES"]?.encrypt(original: self.checkcode) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&phone=" + (phone_ ?? ""))
																					md5.append("&password=" + (password_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postUserReg",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"password",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:password_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"password",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"checkcode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:checkcode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"checkcode",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postUserReg",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retUserReg : BaseITWebAPIBody {
	
	//
						open var userid:String?
    								
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/register"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/register"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		userid = visitableSource.getValue("userid")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postClientLogin : BaseITWebAPIBody {
	
	//
									open var loginname:String?
    							open var password:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogin"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let loginname_ = secureKeys?["AES"]?.encrypt(original: self.loginname) ?? ""
																					let password_ = secureKeys?["AES"]?.encrypt(original: self.password) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&loginname=" + (loginname_ ?? ""))
																					md5.append("&password=" + (password_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postClientLogin",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"loginname",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:loginname_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"loginname",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"password",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:password_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"password",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postClientLogin",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retClientLogin : BaseITWebAPIBody {
	
	//
												open var userid:String?
    							open var phoneno:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogin"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userid = visitableSource.getValue("userid")
																											phoneno = visitableSource.getValue("phoneno")
															}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class PostVCodeLogin : BaseITWebAPIBody {
	
	//
									open var loginname:String?
    							open var vcode:String?
    							open var userToken:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/vcodeLogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/vcodeLogin"
        	}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let loginname_ = secureKeys?["AES"]?.encrypt(original: self.loginname) ?? ""
																					let vcode_ = secureKeys?["AES"]?.encrypt(original: self.vcode) ?? ""
																					let userToken_ = secureKeys?["AES"]?.encrypt(original: self.userToken) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&loginname=" + (loginname_ ?? ""))
																					md5.append("&vcode=" + (vcode_ ?? ""))
																					md5.append("&userToken=" + (userToken_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"PostVCodeLogin",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"loginname",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:loginname_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"loginname",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"vcode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:vcode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"vcode",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"userToken",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:userToken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"userToken",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"PostVCodeLogin",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class RetVCodeLogin : BaseITWebAPIBody {
	
	//
												open var userid:String?
    							open var phoneno:String?
    							open var userToken:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/vcodeLogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/vcodeLogin"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userid = visitableSource.getValue("userid")
																											phoneno = visitableSource.getValue("phoneno")
																											userToken = visitableSource.getValue("userToken")
															}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postTrustLogin : BaseITWebAPIBody {
	
	//
									open var terminalid:String?
    							open var trusttoken:String?
    							open var loginname:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/trustlogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/trustlogin"
        	}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let terminalid_ = secureKeys?["AES"]?.encrypt(original: self.terminalid) ?? ""
																					let trusttoken_ = secureKeys?["AES"]?.encrypt(original: self.trusttoken) ?? ""
																					let loginname_ = secureKeys?["AES"]?.encrypt(original: self.loginname) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&terminalid=" + (terminalid_ ?? ""))
																					md5.append("&trusttoken=" + (trusttoken_ ?? ""))
																					md5.append("&loginname=" + (loginname_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postTrustLogin",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"terminalid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:terminalid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"terminalid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"trusttoken",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:trusttoken_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"trusttoken",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"loginname",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:loginname_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"loginname",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postTrustLogin",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retTrustLogin : BaseITWebAPIBody {
	
	//
												open var userid:String?
    							open var phoneno:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/trustlogin"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/trustlogin"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											userid = visitableSource.getValue("userid")
																											phoneno = visitableSource.getValue("phoneno")
															}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postUpdatePwd : BaseITWebAPIBody {
	
	//
									open var password:String?
    							open var newpassword:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/updatepwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/updatepwd"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let password_ = secureKeys?["AES"]?.encrypt(original: self.password) ?? ""
																					let newpassword_ = secureKeys?["AES"]?.encrypt(original: self.newpassword) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&password=" + (password_ ?? ""))
																					md5.append("&newpassword=" + (newpassword_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postUpdatePwd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"password",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:password_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"password",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"newpassword",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:newpassword_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"newpassword",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postUpdatePwd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retUpdatePwd : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/updatepwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/updatepwd"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postResetPwd : BaseITWebAPIBody {
	
	//
									open var phone:String?
    							open var newpassword:String?
    							open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/resetpwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/resetpwd"
        	}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let phone_ = secureKeys?["AES"]?.encrypt(original: self.phone) ?? ""
																					let newpassword_ = secureKeys?["AES"]?.encrypt(original: self.newpassword) ?? ""
																					let checkcode_ = secureKeys?["AES"]?.encrypt(original: self.checkcode) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&phone=" + (phone_ ?? ""))
																					md5.append("&newpassword=" + (newpassword_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postResetPwd",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"phone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:phone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"phone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"newpassword",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:newpassword_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"newpassword",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"checkcode",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:checkcode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"checkcode",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postResetPwd",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retResetPwd : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/resetpwd"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/resetpwd"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postBindNewPhone : BaseITWebAPIBody {
	
	//
									open var newphone:String?
    							open var checkcode:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/bindnewphone"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/bindnewphone"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let newphone_ = secureKeys?["AES"]?.encrypt(original: self.newphone) ?? ""
																					let checkcode_ = secureKeys?["AES"]?.encrypt(original: self.checkcode) ?? ""
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&newphone=" + (newphone_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postBindNewPhone",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"newphone",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:newphone_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"newphone",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"checkcode",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:checkcode_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"checkcode",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postBindNewPhone",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retBindNewPhone : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/bindnewphone"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/bindnewphone"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postGetMemberInfo : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/getmemberinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/getmemberinfo"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postGetMemberInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"clientid",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postGetMemberInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retGetMemberInfo : BaseITWebAPIBody {
	
	//
												open var loginname:String?
    							open var phone:String?
    							open var regdate:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/getmemberinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/member/getmemberinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
							var md5 = ""
																																					md5 += "loginname=" + visitableSource.getValue("loginname")
																										md5 += "&phone=" + visitableSource.getValue("phone")
																												self.valid = (md5.md5 == visitableSource.getValue("sign"))
				if !self.isValid {
					return
				}
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											loginname = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("loginname"))
																											phone = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("phone"))
																											regdate = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("regdate"))
															}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postClientLogout : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogout"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogout"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postClientLogout",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"clientid",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postClientLogout",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retClientLogout : BaseITWebAPIBody {
	
	//
							
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogout"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/security/clientlogout"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postSysInfo : BaseITWebAPIBody {
	
	//
						open var appid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/sysinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/sysinfo"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("appid=" + (appid_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postSysInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"appid",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postSysInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retSysInfo : BaseITWebAPIBody {
	
	//
												open var bizlistver:String?
    							open var appver:String?
    							open var suminfo:String?
    							open var anncId:String?
    							open var title:String?
    							open var content:String?
    							open var createTime:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/sysinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/sysinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											bizlistver = visitableSource.getValue("bizlistver")
																											appver = visitableSource.getValue("appver")
																											suminfo = visitableSource.getValue("suminfo")
																											anncId = visitableSource.getValue("anncId")
																											title = visitableSource.getValue("title")
																											content = visitableSource.getValue("content")
																											createTime = visitableSource.getValue("createTime")
																											type = visitableSource.getValue("type")
															}

	//-------> one-to-many
			    		    		    		    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postCityListInfo : BaseITWebAPIBody {
	
	//
						open var appid:String?
    							open var businesstype:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
        	}

	//-------> one-to-many
			    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
																					let businesstype_ = self.businesstype;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postCityListInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:3,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:3,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:3,field:"appid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:3,field:"businesstype",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:3,value:businesstype_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:3,field:"businesstype",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"postCityListInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retCityListInfo : BaseITWebAPIBody {
	
	//
												open var citylistver:String?
    				    		//----->one-to-manay
			fileprivate var data = [CityList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											citylistver = visitableSource.getValue("citylistver")
																					//----->one-to-manay
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( CityList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> one-to-many
			    		    		    			    open func addCityList(subBody:CityList) -> Void{
	        data.append(subBody)
	    }

	    open func getCityList() -> [CityList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																								
open class CityList : BaseITWebAPIBody {
	
	//
						open var cityver:String?
    							open var cityid:String?
    							open var tenantid:String?
    							open var cityname:String?
    							open var citycode:String?
    							open var carrierid:String?
    							open var serviceinfo:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citylistinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		cityver = visitableSource.getValue("cityver")
																											cityid = visitableSource.getValue("cityid")
																											tenantid = visitableSource.getValue("tenantid")
																											cityname = visitableSource.getValue("cityname")
																											citycode = visitableSource.getValue("citycode")
																											carrierid = visitableSource.getValue("carrierid")
																											serviceinfo = visitableSource.getValue("serviceinfo")
															}

	//-------> one-to-many
			    		    		    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class postCityBaseInfo : BaseITWebAPIBody {
	
	//
									open var cityid:String?
    							open var appid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
        	}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let cityid_ = self.cityid;
																					let appid_ = self.appid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&cityid=" + (cityid_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postCityBaseInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:4,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:4,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:4,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:4,field:"cityid",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:4,value:cityid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:4,field:"cityid",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:4,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:4,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:4,field:"appid",body:self))
									result.append(vo.onFieldBegin(.flat,index:4,length:4,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:4,length:4,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:4,length:4,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postCityBaseInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retCityBaseInfo : BaseITWebAPIBody {
	
	//
												open var cityver:String?
    							open var cityid:String?
    							open var tenantid:String?
    							open var cityname:String?
    							open var ishttps:String?
    							open var httpsport:String?
    							open var citycode:String?
    							open var carrierid:String?
    							open var carriername:String?
    							open var trademoney:String?
    							open var serviceinfo:String?
    							open var exchangeKey:String?
    				    		//----->one-to-manay
			fileprivate var data = [ServiceInfoList]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																											cityver = visitableSource.getValue("cityver")
																											cityid = visitableSource.getValue("cityid")
																											tenantid = visitableSource.getValue("tenantid")
																											cityname = visitableSource.getValue("cityname")
																											ishttps = visitableSource.getValue("ishttps")
																											httpsport = visitableSource.getValue("httpsport")
																											citycode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("citycode"))
																											carrierid = visitableSource.getValue("carrierid")
																											carriername = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("carriername"))
																											trademoney = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("trademoney"))
																											serviceinfo = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("serviceinfo"))
																											exchangeKey = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("exchangeKey"))
																					//----->one-to-manay
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( ServiceInfoList (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> one-to-many
			    		    		    		    		    		    		    		    		    		    		    		    		    		    			    open func addServiceInfoList(subBody:ServiceInfoList) -> Void{
	        data.append(subBody)
	    }

	    open func getServiceInfoList() -> [ServiceInfoList]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																																																																															
open class ServiceInfoList : BaseITWebAPIBody {
	
	//
						open var name:String?
    							open var serviceinfo:String?
    							open var rule:String?
    							open var remark:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/citybaseinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		name = visitableSource.getValue("name")
																											serviceinfo = visitableSource.getValue("serviceinfo")
																											rule = visitableSource.getValue("rule")
																											remark = visitableSource.getValue("remark")
															}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_login } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class postMemberBizInfo : BaseITWebAPIBody {
	
	//
				
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
														
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postMemberBizInfo",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"clientid",body:self))
									result.append(vo.onFieldBegin(.flat,index:2,length:2,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:2,length:2,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:2,length:2,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postMemberBizInfo",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retMemberBizInfo : BaseITWebAPIBody {
	
	//
									    		//----->one-to-manay
			fileprivate var data = [BizInfo]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																					//----->one-to-manay
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( BizInfo (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> one-to-many
			    		    			    open func addBizInfo(subBody:BizInfo) -> Void{
	        data.append(subBody)
	    }

	    open func getBizInfo() -> [BizInfo]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																			
open class BizInfo : BaseITWebAPIBody {
	
	//
						open var cityid:String?
    							open var cityname:String?
    							open var citycode:String?
    							open var status:String?
    							open var carrierid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/business/memberbizinfo"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		cityid = visitableSource.getValue("cityid")
																											cityname = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("cityname"))
																											citycode = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("citycode"))
																											status = secureKeys["AES"]?.decrypt(original: visitableSource.getValue("status"))
																											carrierid = visitableSource.getValue("carrierid")
															}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class postSubmitMail : BaseITWebAPIBody {
	
	//
						open var title:String?
    							open var content:String?
    										open var cityId:String?
    							open var appid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/submitMail"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/submitMail"
        	}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let title_ = self.title;
																					let content_ = self.content;
																					let clientid_ = self.clientid;
																					let cityId_ = self.cityId;
																					let appid_ = self.appid;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postSubmitMail",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:6,field:"title",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:6,value:title_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:6,field:"title",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:6,field:"content",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:6,value:content_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:6,field:"content",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:6,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:6,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:6,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:6,field:"cityId",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:6,value:cityId_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:6,field:"cityId",body:self))
												result.append(vo.onFieldBegin(.flat,index:5,length:6,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:5,length:6,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:5,length:6,field:"appid",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"postSubmitMail",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retSubmitMail : BaseITWebAPIBody {
	
	//
						open var mailid:String?
    								
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/submitMail"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/submitMail"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		mailid = visitableSource.getValue("mailid")
																											retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
															}

	//-------> one-to-many
			    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }

		
open class postListMail : BaseITWebAPIBody {
	
	//
									open var start:String?
    							open var limit:String?
    							open var appid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
        	}

	//-------> one-to-many
			    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let clientid_ = self.clientid;
																					let start_ = self.start;
																					let limit_ = self.limit;
																					let appid_ = self.appid;
									
		//====   md5 check   ====
					var md5:[String] = []
															md5.append("clientid=" + (clientid_ ?? ""))
																					md5.append("&start=" + (start_ ?? ""))
																					md5.append("&limit=" + (limit_ ?? ""))
																					
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postListMail",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:5,field:"clientid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:5,value:clientid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:5,field:"clientid",body:self))
												result.append(vo.onFieldBegin(.flat,index:2,length:5,field:"start",body:self))
				result.append(vo.onFieldValue(.flat,index:2,length:5,value:start_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:2,length:5,field:"start",body:self))
												result.append(vo.onFieldBegin(.flat,index:3,length:5,field:"limit",body:self))
				result.append(vo.onFieldValue(.flat,index:3,length:5,value:limit_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:3,length:5,field:"limit",body:self))
												result.append(vo.onFieldBegin(.flat,index:4,length:5,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:4,length:5,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:4,length:5,field:"appid",body:self))
									result.append(vo.onFieldBegin(.flat,index:5,length:5,field:"sign",body:self))
		result.append(vo.onFieldValue(.flat,index:5,length:5,value:md5.joined(separator:"").md5,body:self))
		result.append(vo.onFieldEnd(.flat,index:5,length:5,field:"sign",body:self))
				result.append(vo.onObjectEnd(index,length:length,objname:"postListMail",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retListMail : BaseITWebAPIBody {
	
	//
									    		//----->one-to-manay
			fileprivate var data = [ListMail]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																					//----->one-to-manay
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( ListMail (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> one-to-many
			    		    			    open func addListMail(subBody:ListMail) -> Void{
	        data.append(subBody)
	    }

	    open func getListMail() -> [ListMail]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																			
open class ListMail : BaseITWebAPIBody {
	
	//
						open var id:String?
    							open var tilte:String?
    							open var content:String?
    							open var reply:String?
    							open var createTime:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listMail"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		id = visitableSource.getValue("id")
																											tilte = visitableSource.getValue("tilte")
																											content = visitableSource.getValue("content")
																											reply = visitableSource.getValue("reply")
																											createTime = visitableSource.getValue("createTime")
															}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_normal } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}

		
open class postListAnnc : BaseITWebAPIBody {
	
	//
						open var appid:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
        	}

	//-------> one-to-many
			    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

		override open func encode(_ index:UInt8,length:UInt8,visitableObject:ITVisitableObject?,secureKeys:[String:ITSecureKey]?) -> String?{
		guard let vo = visitableObject else {
            return nil
        }

		//====encrypt field====
														let appid_ = self.appid;
									
		//====   md5 check   ====
		
		//====serialize field====
		var result:[String] = []
		result.append(vo.onObjectBegin(index,length:length,objname:"postListAnnc",body:self))
											result.append(vo.onFieldBegin(.flat,index:1,length:2,field:"appid",body:self))
				result.append(vo.onFieldValue(.flat,index:1,length:2,value:appid_ ?? "",body:self))
				result.append(vo.onFieldEnd(.flat,index:1,length:2,field:"appid",body:self))
									result.append(vo.onObjectEnd(index,length:length,objname:"postListAnnc",body:self))
		return result.joined(separator:"")
	}
	
	open func isRequestBody() -> Bool{
    	return true;
    }
    }

		
open class retListAnnc : BaseITWebAPIBody {
	
	//
									    		//----->one-to-manay
			fileprivate var data = [ListAnnc]()
			//>-----
			
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		retcode = visitableSource.getValue("retcode")
																											retmsg = visitableSource.getValue("retmsg")
																					//----->one-to-manay
					for visitableSource in visitableSource.getSubSource("data") {
						data .append( ListAnnc (visitableSource:visitableSource,secureKeys:secureKeys))
					}
					//>-----
										}

	//-------> one-to-many
			    		    			    open func addListAnnc(subBody:ListAnnc) -> Void{
	        data.append(subBody)
	    }

	    open func getListAnnc() -> [ListAnnc]{
	        return data
	    }
	        
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    																			
open class ListAnnc : BaseITWebAPIBody {
	
	//
						open var anncId:String?
    							open var title:String?
    							open var content:String?
    							open var createTime:String?
    							open var type:String?
    		
	required public init(){
		super.init()
		self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
	}

	required public convenience init(visitableSource:ITVisitableSource,secureKeys:[String:ITSecureKey]){
        self.init()
        self.appId_ = "27"
		self.appName_ = "mt"
		self.mapping_ = "/bikemt/manager/listAnnc"
        			//====   md5 check   ====
			if !String.isEmpty(visitableSource.getValue("sign")) {
						}
																		anncId = visitableSource.getValue("anncId")
																											title = visitableSource.getValue("title")
																											content = visitableSource.getValue("content")
																											createTime = visitableSource.getValue("createTime")
																											type = visitableSource.getValue("type")
															}

	//-------> one-to-many
			    		    		    		    		    
	override open var serverMode:ITSeverMode { get { return .sermode_no_session } }

	
	open func isRequestBody() -> Bool{
    	return false;
    }
    }
						}
